@@ -91,7 +91,9 @@
 #ifndef _WIN32
 
 #include <langinfo.h>
+#ifndef O_BINARY    /* Cygwin, others? */
 #define O_BINARY 0
+#endif
 
 #ifdef HAVE_RECODE_H
 #define WITH_RECODE
@@ -104,8 +106,12 @@
 #endif
 
 #ifdef HAVE_REGEX_H
+#ifdef HAVE_PCRE2
+#include <pcre2posix.h>
+#else
 #include <regex.h>
 #endif
+#endif
 
 #define MINW 6   /* minimum wait if desired */
 #define CPERS 20 /* # of chars for each sec */
@@ -334,7 +340,7 @@ static char *conv_pat(const char *const orig_str)
     char *new_buf;
 
     size_t cnt = 1; /* allow for '\0' */
-    for (sp = orig_str; *sp != '\0'; sp++)
+    for (sp = orig_str; *sp != '\0'; ++sp)
     {
         const size_t prev_cnt = cnt;
         if (isalpha(*sp))
@@ -408,9 +414,7 @@ static void *do_malloc(const size_t size)
  */
 static FILEDESC *new_fp(void)
 {
-    FILEDESC *fp;
-
-    fp = do_malloc(sizeof *fp);
+    FILEDESC *const fp = do_malloc(sizeof *fp);
     fp->datfd = -1;
     fp->pos = POS_UNKNOWN;
     fp->inf = NULL;
@@ -585,7 +589,6 @@ static int add_file(int percent, const char *file, const char *dir,
     FILEDESC *fp;
     int fd = -1;
     char *path;
-    char *sp;
     struct stat statbuf;
 
     if (!dir)
@@ -1885,7 +1888,7 @@ static void free_desc(FILEDESC *ptr)
             fclose(ptr->inf);
             ptr->inf = NULL;
         }
-        FILEDESC *next = ptr->next;
+        FILEDESC *const next = ptr->next;
         free(ptr);
         ptr = next;
     }
